@@ -1,9 +1,22 @@
+# QUANTCONNECT.COM - Democratizing Finance, Empowering Individuals.
+# Lean CLI v1.0. Copyright 2021 QuantConnect Corporation.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from pathlib import Path
 from typing import Optional
 
 import click
 
-from lean.config import Config
+from lean.constants import DEFAULT_LEAN_CONFIG_FILE_NAME
 from lean.container import container
 
 
@@ -18,35 +31,52 @@ def parse_verbose_option(ctx: click.Context, param: click.Parameter, value: Opti
     """Parses the --verbose option."""
     if value:
         logger = container.logger()
-        logger.debug_logging_enabled = True
+        logger.enable_debug_logging()
 
 
 class LeanCommand(click.Command):
     """A click.Command wrapper with some Lean CLI customization."""
 
-    def __init__(self, requires_project: bool = False, *args, **kwargs):
+    def __init__(self, requires_cli_project: bool = False, *args, **kwargs):
         """Creates a new LeanCommand instance.
 
-        :param requires_project: True if this command needs to be ran in a Lean CLI project, False if not
+        :param requires_cli_project: True if this command needs to be ran in a Lean CLI project, False if not
         :param args: the args that are passed on to the click.Command constructor
         :param kwargs: the kwargs that are passed on to the click.Command constructor
         """
-        self._requires_project = requires_project
+        self._requires_cli_project = requires_cli_project
 
         super().__init__(*args, **kwargs)
 
-        # By default the width of help messages is min(terminal_width, max_terminal_width)
-        # max_terminal_width defaults to 80, which we increase to 120 to improve readability on wide terminals
+        # By default the width of help messages is min(terminal_width, max_content_width)
+        # max_content_width defaults to 80, which we increase to 120 to improve readability on wide terminals
         self.context_settings["max_content_width"] = 120
 
+    def invoke(self, ctx):
+        if self._requires_cli_project:
+            try:
+                # This method will throw if the directory cannot be found
+                container.lean_config_manager().get_cli_root_directory()
+            except Exception:
+                # Abort with a display-friendly error message if the command needs to be ran inside a Lean CLI project
+                raise RuntimeError(
+                    "This command should be executed in a Lean CLI project, run `lean init` in an empty directory to create one or specify the Lean configuration file to use with --lean-config")
+
+        result = super().invoke(ctx)
+
+        update_manager = container.update_manager()
+        update_manager.warn_if_cli_outdated()
+
+        return result
+
     def get_params(self, ctx):
         params = super().get_params(ctx)
 
         # Add --config option if the commands needs to be ran inside a Lean CLI project
-        if self._requires_project:
-            params += [click.Option(["--config", "-c"],
+        if self._requires_cli_project:
+            params += [click.Option(["--lean-config"],
                                     type=PathParameter(exists=True, file_okay=True, dir_okay=False),
-                                    help=f"The configuration file that should be used (defaults to the nearest {Config.default_lean_config_file_name})",
+                                    help=f"The Lean configuration file that should be used (defaults to the nearest {DEFAULT_LEAN_CONFIG_FILE_NAME})",
                                     expose_value=False,
                                     is_eager=True,
                                     callback=parse_config_option)]
@@ -67,10 +97,8 @@ class LeanCommand(click.Command):
 class PathParameter(click.ParamType):
     """A limited version of click.Path which uses pathlib.Path."""
 
-    name = "path"
-
     def __init__(self, exists: bool = False, file_okay: bool = True, dir_okay: bool = True):
-        """Creates a new Path instance.
+        """Creates a new PathParameter instance.
 
         :param exists: True if the path needs to point to an existing object, False if not
         :param file_okay: True if the path may point to a file, False if not
@@ -91,7 +119,7 @@ class PathParameter(click.ParamType):
             self._path_type = "Path"
 
     def convert(self, value: str, param: click.Parameter, ctx: click.Context) -> Path:
-        path = Path(value).resolve()
+        path = Path(value).expanduser().resolve()
 
         if self._exists and not path.exists():
             self.fail(f"{self._path_type} '{value}' does not exist.", param, ctx)
