@@ -1,4 +1,18 @@
+# QUANTCONNECT.COM - Democratizing Finance, Empowering Individuals.
+# Lean CLI v1.0. Copyright 2021 QuantConnect Corporation.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import shutil
+import sys
 import tempfile
 import zipfile
 from pathlib import Path
@@ -7,7 +21,7 @@ import click
 import requests
 
 from lean.click import LeanCommand
-from lean.config import Config
+from lean.constants import DEFAULT_DATA_DIRECTORY_NAME, DEFAULT_LEAN_CONFIG_FILE_NAME
 from lean.container import container
 
 CSPROJ = """
@@ -30,7 +44,7 @@ on the page above, you can add a PackageReference for it.
         <Platform Condition=" '$(Platform)' == '' ">AnyCPU</Platform>
         <TargetFramework>net462</TargetFramework>
         <LangVersion>6</LangVersion>
-        <OutputPath>bin\$(Configuration)\</OutputPath>
+        <OutputPath>bin/$(Configuration)</OutputPath>
         <AppendTargetFrameworkToOutputPath>false</AppendTargetFrameworkToOutputPath>
     </PropertyGroup>
      <PropertyGroup>
@@ -65,7 +79,7 @@ on the page above, you can add a PackageReference for it.
         </When>
     </Choose>
     <ItemGroup>
-        <PackageReference Include="QuantConnect.Lean" Version="*"/>
+        <PackageReference Include="QuantConnect.Lean" Version="2.*"/>
     </ItemGroup>
 </Project>
 """.strip() + "\n"
@@ -142,13 +156,19 @@ VSCODE_LAUNCH_JSON = """
 }
 """.strip() + "\n"
 
+VSCODE_SETTINGS_JSON = """
+{
+    "python.pythonPath": "$PYTHON$"
+}
+""".strip() + "\n"
+
 
 @click.command(cls=LeanCommand)
 def init() -> None:
     """Bootstrap a Lean CLI project."""
     current_dir = Path.cwd()
-    data_dir = current_dir / Config.default_data_directory_name
-    lean_config_path = current_dir / Config.default_lean_config_file_name
+    data_dir = current_dir / DEFAULT_DATA_DIRECTORY_NAME
+    lean_config_path = current_dir / DEFAULT_LEAN_CONFIG_FILE_NAME
 
     # Abort if one of the files we are going to create already exists to prevent us from overriding existing files
     for path in [data_dir, lean_config_path]:
@@ -190,7 +210,7 @@ def init() -> None:
     config = lean_config_manager.clean_lean_config(config)
 
     # Update the data-folder configuration
-    config = config.replace('"data-folder": "../../../Data/"', f'"data-folder": "{Config.default_data_directory_name}"')
+    config = config.replace('"data-folder": "../../../Data/"', f'"data-folder": "{DEFAULT_DATA_DIRECTORY_NAME}"')
 
     with lean_config_path.open("w+") as file:
         file.write(config)
@@ -200,7 +220,8 @@ def init() -> None:
         "LeanCLI.csproj": CSPROJ,
         ".idea/workspace.xml": PYCHARM_WORKSPACE_XML,
         ".idea/.idea.LeanCLI.dir/.idea/workspace.xml": RIDER_WORKSPACE_XML,
-        ".vscode/launch.json": VSCODE_LAUNCH_JSON
+        ".vscode/launch.json": VSCODE_LAUNCH_JSON,
+        ".vscode/settings.json": VSCODE_SETTINGS_JSON.replace("$PYTHON$", sys.executable)
     }
 
     for location, content in extra_files.items():
@@ -220,10 +241,10 @@ def init() -> None:
 Successfully bootstrapped your Lean CLI project!
 
 The following structure has been created:
-- {Config.default_lean_config_file_name} contains the configuration used when running the LEAN engine locally
-- {Config.default_data_directory_name}/ contains the data that is used when running the LEAN engine locally
+- {DEFAULT_LEAN_CONFIG_FILE_NAME} contains the configuration used when running the LEAN engine locally
+- {DEFAULT_DATA_DIRECTORY_NAME}/ contains the data that is used when running the LEAN engine locally
 
 Here are some commands to get you going:
 - Run `lean create-project "My Project"` to create a new project with starter code
-- Run `lean backtest "My Project"` to backtest a project locally with the data in {Config.default_data_directory_name}/
+- Run `lean backtest "My Project"` to backtest a project locally with the data in {DEFAULT_DATA_DIRECTORY_NAME}/
 """.strip())
